@@ -16,16 +16,38 @@ coef.emaxsim<-function(object, ...){
 }
 
 ####
-coef.fitEmaxB<-function(object, ...){
+coef.fitEmaxB<-function(object, local=FALSE, ...){
 	binary<-object$binary
 	matm<-as.matrix(object$estanfit)	
-	if(binary)nc<-ncol(matm)-1 else nc<-ncol(matm)-2
-	return(matm[,1:nc])
+	localParm<-object$localParm
+	if(is.null(localParm))localParm<-FALSE
+	if(local & !localParm)stop('local=TRUE but no local parameters fit')
+	
+	if(local){
+		nc<-1
+		matm<-matm[,'difTarget',drop=FALSE]
+	}else{
+		if(localParm){ 
+			if(binary)nc<-ncol(matm)-3 else nc<-ncol(matm)-4
+		}else  if(binary)nc<-ncol(matm)-1 else nc<-ncol(matm)-2
+	}
+	
+	return(matm[,1:nc,drop=FALSE])
 }
 
 ####
-coef.emaxsimB<-function(object, ...){
-	return(object$est)
+coef.emaxsimB<-function(object, local=FALSE, ...){
+	localParm<-object$localParm
+	if(is.null(localParm))localParm<-FALSE
+	if(local & !localParm)stop('local=TRUE but no local parameters fit')
+	
+	est<-object$est
+	nc<-ncol(est)
+	if((localParm) && local){
+		est<-est[,nc,drop=FALSE]
+	}else if(localParm)est<-est[,1:(nc-1)]
+	
+	return(est)
 }
 
 ####
@@ -52,7 +74,7 @@ sigma.fitEmaxB<-function(object, ...){
 		return(NA)
 	}else{
 		matm<-as.matrix(object$estanfit)	
-		return(as.vector(matm[,ncol(matm)-1]))
+		return(as.vector(matm[,'sigma[1]']))
 	}
 }
 #####
